=======
History
=======
1.1.0 (2020-06-11)
Various extra functionality added, including non-GR polarizations and pulsar term flags.
1.0.5 (2019-10-21)
JOSS/Zenodo Release with various changes from JOSS Refereeing and correct Zenodo `.json`
1.0.4 (2019-10-21)
JOSS/Zenodo Release with various changes from JOSS Refereeing and correct Zenodo `.json`
1.0.3 (2019-10-21)
JOSS/Zenodo Release with various changes from JOSS Refereeing and correct Zenodo `.json`
1.0.2 (2019-10-21)
JOSS/Zenodo Release with various changes from JOSS Refereeing and correct Zenodo `.json`
1.0.1 (2019-10-21)
JOSS/Zenodo Release with various changes from JOSS Refereeing
1.0.0 (2019-09-20)
The Official Release.
0.1.6 (2019-08-30)
0.1.6 (2019-08-29)
0.1.5 (2019-08-13)
0.1.4 (2019-08-13)
0.1.3 (2019-08-13)
0.1.2 (2019-06-23)
0.1.1 (2019-06-23)
0.1.0 (2019-06-23)*
------------------

* First release on PyPI.
